@@ -1,4 +1,6 @@
 import requests
+from stl_sdk.exceptions import CoreHttpError
+from requests.exceptions import HTTPError
 
 
 class TorpedoClient:
@@ -11,7 +13,7 @@ class TorpedoClient:
 
     def __init__(self, torpedo_url, client_name):
 
-        self.torpedo_url = torpedo_url
+        self.torpedo_url = torpedo_url.strip('/')
         self.client_name = client_name
 
     def send_email(self, email, subject, template_name, data=None):
@@ -38,15 +40,22 @@ class TorpedoClient:
         :return: Resposta da requisição para o Mailgun
         :rtype: requests.Response
         """
-        response = requests.post(
-                '{}/api/send-email'.format(self.torpedo_url),
-                json={
-                    'to_email': email,
-                    'subject': subject,
-                    'template_name': template_name,
-                    'data': data,
-                    'client': self.client_name,
-                }
-            )
-        response.raise_for_status()
-        return response
+        try:
+            response = requests.post(
+                    '{}/api/send-email'.format(self.torpedo_url),
+                    json={
+                        'to_email': email,
+                        'subject': subject,
+                        'template_name': template_name,
+                        'data': data,
+                        'client': self.client_name,
+                    }
+                )
+            response.raise_for_status()
+            return response
+        except HTTPError as error:
+            raise TorpedoClientHTTPError(error) from error
+
+
+class TorpedoClientHTTPError(CoreHttpError):
+    pass
